@@ -1,12 +1,14 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-"Journal"
+from __future__ import with_statement
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
 from trytond.backend import TableHandler
+from trytond.pyson import Equal, Eval, Not, Get, Or, And, Bool
+from trytond.transaction import Transaction
 
 STATES = {
-    'readonly': "state == 'close'",
+    'readonly': Equal(Eval('state'), 'close'),
 }
 DEPENDS = ['state']
 
@@ -63,10 +65,10 @@ class Column(ModelSQL, ModelView):
         super(Column, self).__init__()
         self._order.insert(0, ('sequence', 'ASC'))
 
-    def default_required(self, cursor, user, context=None):
+    def default_required(self):
         return False
 
-    def default_readonly(self, cursor, user, context=None):
+    def default_readonly(self):
         return False
 
 Column()
@@ -84,78 +86,80 @@ class Journal(ModelSQL, ModelView):
     view = fields.Many2One('account.journal.view', 'View')
     centralised = fields.Boolean('Centralised counterpart')
     update_posted = fields.Boolean('Allow cancelling moves')
-    sequence = fields.Property(type='many2one', relation='ir.sequence',
-            string='Sequence', required=True,
-            domain=[('code', '=', 'account.journal')],
-            context={'code': 'account.journal'})
-    credit_account = fields.Property(type='many2one',
-            relation='account.account', string='Default Credit Account',
-            domain=[('kind', '!=', 'view'),
-                "('company', '=', context.get('company'))"],
-            states={
-                'required': "centralised or " \
-                        "(type == 'cash' and context.get('company'))",
-                'invisible': "not context.get('company')",
-            }, depends=['type', 'centralised'])
-    debit_account = fields.Property(type='many2one',
-            relation='account.account', string='Default Debit Account',
-            domain=[('kind', '!=', 'view'),
-                "('company', '=', context.get('company'))"],
-            states={
-                'required': "centralised or " \
-                        "(type == 'cash' and context.get('company'))",
-                'invisible': "not context.get('company')",
-            }, depends=['type', 'centralised'])
+    sequence = fields.Property(fields.Many2One('ir.sequence', 'Sequence',
+        domain=[('code', '=', 'account.journal')],
+        context={'code': 'account.journal'},
+        states={
+            'required': Bool(Get(Eval('context', {}), 'company', 0)),
+        }))
+    credit_account = fields.Property(fields.Many2One('account.account',
+        'Default Credit Account', domain=[
+            ('kind', '!=', 'view'),
+            ('company', '=', Get(Eval('context', {}), 'company', 0)),
+        ],
+        states={
+            'required': And(Or(Bool(Eval('centralised')),
+                Equal(Eval('type'), 'cash')),
+                Bool(Get(Eval('context', {}), 'company', 0))),
+            'invisible': Not(Bool(Get(Eval('context', {}), 'company', 0))),
+        }, depends=['type', 'centralised']))
+    debit_account = fields.Property(fields.Many2One('account.account',
+        'Default Debit Account', domain=[
+            ('kind', '!=', 'view'),
+            ('company', '=', Get(Eval('context', {}), 'company', 0)),
+        ],
+        states={
+            'required': And(Or(Bool(Eval('centralised')),
+                Equal(Eval('type'), 'cash')),
+                Bool(Get(Eval('context', {}), 'company', 0))),
+            'invisible': Not(Bool(Get(Eval('context', {}), 'company', 0))),
+        }, depends=['type', 'centralised']))
 
     def __init__(self):
         super(Journal, self).__init__()
         self._order.insert(0, ('name', 'ASC'))
 
-    def init(self, cursor, module_name):
-        super(Journal, self).init(cursor, module_name)
+    def init(self, module_name):
+        super(Journal, self).init(module_name)
+        cursor = Transaction().cursor
         table = TableHandler(cursor, self, module_name)
 
         # Migration from 1.0 sequence Many2One change into Property
         if table.column_exist('sequence'):
             property_obj = self.pool.get('ir.property')
             cursor.execute('SELECT id, sequence FROM "' + self._table +'"')
-            for journal_id, sequence_id in cursor.fetchall():
-                property_obj.set(cursor, 0, 'sequence', self._name,
-                        journal_id, (sequence_id and \
+            with Transaction().set_user(0):
+                for journal_id, sequence_id in cursor.fetchall():
+                    property_obj.set('sequence', self._name,
+                            journal_id, (sequence_id and
                                 'ir.sequence,' + str(sequence_id) or False))
             table.drop_column('sequence', exception=True)
 
-    def default_active(self, cursor, user, context=None):
+    def default_active(self):
         return True
 
-    def default_centralised(self, cursor, user, context=None):
+    def default_centralised(self):
         return False
 
-    def default_update_posted(self, cursor, user, context=None):
+    def default_update_posted(self):
         return False
 
-    def default_sequence(self, cursor, user, context=None):
+    def default_sequence(self):
         return False
 
-    def get_types(self, cursor, user, context=None):
+    def get_types(self):
         type_obj = self.pool.get('account.journal.type')
-        type_ids = type_obj.search(cursor, user, [], context=context)
-        types = type_obj.browse(cursor, user, type_ids, context=context)
+        type_ids = type_obj.search([])
+        types = type_obj.browse(type_ids)
         return [(x.code, x.name) for x in types]
 
-    def search_rec_name(self, cursor, user, name, args, context=None):
-        args2 = []
-        i = 0
-        while i < len(args):
-            ids = self.search(cursor, user, [
-                ('code', args[i][1], args[i][2]),
-                ], limit=1, context=context)
-            if ids:
-                args2.append(('code', args[i][1], args[i][2]))
-            else:
-                args2.append((self._rec_name, args[i][1], args[i][2]))
-            i += 1
-        return args2
+    def search_rec_name(self, name, clause):
+        ids = self.search([
+            ('code',) + tuple(clause[1:]),
+            ], limit=1, order=[])
+        if ids:
+            return [('code',) + tuple(clause[1:])]
+        return [(self._rec_name,) + tuple(clause[1:])]
 
 Journal()
 
@@ -170,7 +174,7 @@ class Period(ModelSQL, ModelView):
             ondelete='CASCADE', states=STATES, depends=DEPENDS)
     period = fields.Many2One('account.period', 'Period', required=True,
             ondelete='CASCADE', states=STATES, depends=DEPENDS)
-    icon = fields.Function('get_icon', string='Icon', type='char')
+    icon = fields.Function(fields.Char('Icon'), 'get_icon')
     active = fields.Boolean('Active', select=2, states=STATES, depends=DEPENDS)
     state = fields.Selection([
         ('open', 'Open'),
@@ -193,69 +197,60 @@ class Period(ModelSQL, ModelView):
                     'a journal - period from a closed period!',
             })
 
-    def default_active(self, cursor, user, context=None):
+    def default_active(self):
         return True
 
-    def default_state(self, cursor, user, context=None):
+    def default_state(self):
         return 'open'
 
-    def get_icon(self, cursor, user, ids, name, arg, context=None):
+    def get_icon(self, ids, name):
         res = {}
-        for period in self.browse(cursor, user, ids, context=context):
+        for period in self.browse(ids):
             res[period.id] = _ICONS.get(period.state, '')
         return res
 
-    def _check(self, cursor, user, ids, context=None):
+    def _check(self, ids):
         move_obj = self.pool.get('account.move')
-        for period in self.browse(cursor, user, ids, context=context):
-            move_ids = move_obj.search(cursor, user, [
+        for period in self.browse(ids):
+            move_ids = move_obj.search([
                 ('journal', '=', period.journal.id),
                 ('period', '=', period.period.id),
-                ], limit=1, context=context)
+                ], limit=1)
             if move_ids:
-                self.raise_user_error(cursor, 'modify_del_journal_period',
-                        context=context)
+                self.raise_user_error('modify_del_journal_period')
         return
 
-    def create(self, cursor, user, vals, context=None):
+    def create(self, vals):
         period_obj = self.pool.get('account.period')
         if vals.get('period'):
-            period = period_obj.browse(cursor, user, vals['period'],
-                    context=context)
+            period = period_obj.browse(vals['period'])
             if period.state == 'close':
-                self.raise_user_error(cursor, 'create_journal_period',
-                        context=context)
-        return super(Period, self).create(cursor, user, vals, context=context)
+                self.raise_user_error('create_journal_period')
+        return super(Period, self).create(vals)
 
-    def write(self, cursor, user, ids, vals, context=None):
+    def write(self, ids, vals):
         if vals != {'state': 'close'} \
                 and vals != {'state': 'open'}:
-            self._check(cursor, user, ids, context=context)
+            self._check(ids)
         if vals.get('state') == 'open':
-            for journal_period in self.browse(cursor, user, ids,
-                    context=context):
+            for journal_period in self.browse(ids):
                 if journal_period.period.state == 'close':
-                    self.raise_user_error(cursor, 'open_journal_period',
-                            context=context)
-        return super(Period, self).write(cursor, user, ids, vals,
-                context=context)
+                    self.raise_user_error('open_journal_period')
+        return super(Period, self).write(ids, vals)
 
-    def delete(self, cursor, user, ids, context=None):
-        self._check(cursor, user, ids, context=context)
-        return super(Period, self).delete(cursor, user, ids, context=context)
+    def delete(self, ids):
+        self._check(ids)
+        return super(Period, self).delete(ids)
 
-    def close(self, cursor, user, ids, context=None):
+    def close(self, ids):
         '''
         Close journal - period
 
-        :param cursor: the database cursor
-        :param user: the user id
         :param ids: the journal - period ids
-        :param context: the context
         '''
-        self.write(cursor, user, ids, {
+        self.write(ids, {
             'state': 'close',
-            }, context=context)
+            })
 
 Period()
 
@@ -273,10 +268,9 @@ class ClosePeriod(Wizard):
         },
     }
 
-    def _close(self, cursor, user, data, context=None):
+    def _close(self, data):
         journal_period_obj = self.pool.get('account.journal.period')
-        journal_period_obj.close(cursor, user, data['ids'],
-                context=context)
+        journal_period_obj.close(data['ids'])
         return {}
 
 ClosePeriod()
@@ -295,11 +289,11 @@ class ReOpenPeriod(Wizard):
         },
     }
 
-    def _reopen(self, cursor, user, data, context=None):
+    def _reopen(self, data):
         journal_period_obj = self.pool.get('account.journal.period')
-        journal_period_obj.write(cursor, user, data['ids'], {
+        journal_period_obj.write(data['ids'], {
             'state': 'open',
-            }, context=context)
+            })
         return {}
 
 ReOpenPeriod()
